@@ -1,7 +1,10 @@
 """Authentication schemes exported by module
 """
+from typing import Optional
+
 from django.contrib.auth.models import AnonymousUser
 
+from rest_framework.request import Request
 from rest_framework_simplejwt.exceptions import TokenError
 from rest_framework_simplejwt.authentication import JWTAuthentication
 
@@ -15,7 +18,7 @@ class GCPTokenAuthentication(JWTAuthentication):
        The JWT token must contain the email claim and the email must be in
        the list of ALLOWED_SERVICE_ACCOUNTS in your settings.
     """
-    def authenticate(self, request):
+    def authenticate(self, request: Request) -> Optional[AnonymousUser]:
         """Perform authentication and return the user in the audience.
         """
         header = self.get_header(request)
@@ -32,8 +35,12 @@ class GCPTokenAuthentication(JWTAuthentication):
         if not payload:
             return None
 
-        try:
-            token = IdentityToken(payload['aud'])
-            return token.get_user(), gcp_token
-        except TokenError:
+        id_token_header = request.headers.get('X-GCP-IDTOKEN')
+        if id_token_header:
+            try:
+                token = IdentityToken(id_token_header)
+                return token.get_user(), gcp_token
+            except TokenError:
+                return AnonymousUser(), gcp_token
+        else:
             return AnonymousUser(), gcp_token
